%define major 26
%define libname %mklibname exiv2_ %{major}
%define libdev %mklibname exiv2 -d

Summary:	Command line tool to access EXIF data in image files
Name:		exiv2
Version:	0.26
%define subrel 2
Release:	%mkrel 2
License:	GPLv2+
Group:		Graphics/Utilities
Url:		http://www.exiv2.org/
Source:		http://www.exiv2.org/%{name}-%{version}.tar.gz
Patch1:		exiv2-0.24-parallel-build.patch
Patch2:		exiv2-0.26-pentax-segfault.patch
Patch3:		exiv2-0.26-seventeen-CVE.patch

BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	python
BuildRequires:	libxslt-proc
BuildRequires:	expat-devel
BuildRequires:	zlib-devel

BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libssh)

%description
Exiv2 is a command line utility to access image metadata:
* print the Exif metadata of JPEG, TIFF and several RAW image formats as
  summary info, interpreted values, or the plain data for each tag
* print the IPTC metadata of JPEG images
* print, set and delete the JPEG comment of JPEG images
* set, add and delete Exif and IPTC metadata of JPEG images
* adjust the Exif timestamp (that's how it all started...)
* rename Exif image files according to the Exif timestamp
* extract, insert and delete Exif metadata, IPTC metadata and JPEG comments
* extract, insert and delete the thumbnail image embedded in the Exif metadata
* fix the Exif ISO setting of picture taken with Nikon cameras

%package -n	%{libname}
Summary:	Library to access EXIF data in image files
Group:		Graphics/Utilities
Obsoletes:	%{_lib}exiv22 < 0.16-1
 
%description -n	%{libname}
libexiv2 is a C++ library to access image metadata. libexiv2 is free
software.

The Exiv2 library provides:
* full read and write access to the Exif and IPTC metadata of
  an image through Exiv2 keys and standard C++ iterators
* a smart IPTC implementation that does not affect data that
  programs like Photoshop store in the same image segment
* Exif MakerNote support:
      o MakerNote tags can be accessed just like any other Exif metadata
      o a sophisticated write algorithm avoids corrupting the MakerNote:
          1) the MakerNote is not re-located if possible at all, and
          2) MakerNote Ifd offsets are re-calculated if the MakerNote 
             needs to be moved (for known Ifd MakerNotes)
* extract and delete methods for Exif thumbnails (both, JPEG and TIFF
  thumbnails)
* set methods for Exif thumbnails (JPEG only, TIFF thumbnails can be
  set from individual tags)
* complete API documentation (by Doxygen)

%package -n	%{libdev}
Summary: 	Headers and links to compile against the "%{libname}" library
Requires: 	%{libname} = %{version}
Requires:       multiarch-utils
Provides:	libexiv-devel = %{version}
Group:		Development/C

%description -n	%{libdev}
This package contains all files which one needs to compile programs using
the "%{libname}" library.

%package	doc
Summary:	Exiv2 library documentation
Group:		Documentation
BuildArch:	noarch

%description	doc
Exiv2 library documentation.

%prep
%setup -q 
%autopatch -p1

%build
# exiv2: embedded copy of exempi should be compiled with BanAllEntityUsage
# https://bugzilla.redhat.com/show_bug.cgi?id=888769
export CPPFLAGS="-DBanAllEntityUsage=1"
export MAKEFILES_TYPE='Unix Makefiles'
%cmake -G "$MAKEFILES_TYPE" \
      -DEXIV2_ENABLE_SHARED=ON \
      -DEXIV2_ENABLE_XMP=ON \
      -DEXIV2_ENABLE_LIBXMP=ON \
      -DEXIV2_ENABLE_PNG=ON \
      -DEXIV2_ENABLE_NLS=ON \
      -DEXIV2_ENABLE_PRINTUCS2=ON \
      -DEXIV2_ENABLE_LENSDATA=ON \
      -DEXIV2_ENABLE_COMMERCIAL=OFF \
      -DEXIV2_ENABLE_BUILD_SAMPLES=OFF \
      -DEXIV2_ENABLE_BUILD_PO=ON \
      -DEXIV2_ENABLE_VIDEO=OFF \
      -DEXIV2_ENABLE_WEBREADY=OFF \
      -DEXIV2_ENABLE_CURL=OFF \
      -DEXIV2_ENABLE_SSH=OFF 
%make
%install
%makeinstall_std -C build

%find_lang exiv2

rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_libdir}/*.a
%files  -f %{name}.lang
%doc COPYING README
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{libdev}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*
%{_includedir}/*

%files doc
%doc doc/ChangeLog doc/cmd.txt 


%changelog
* Thu Oct 26 2017 mrambo3501 <mrambo3501> 0.26-2.2.mga6
+ Revision: 1173836
- add upstream patch fixing multiple CVEs
- * CVE-2017-11336
- * CVE-2017-11337
- * CVE-2017-11338
- * CVE-2017-11339
- * CVE-2017-11340
- * CVE-2017-11553
- * CVE-2017-11591
- * CVE-2017-11592
- * CVE-2017-11683
- * CVE-2017-12955
- * CVE-2017-12956
- * CVE-2017-12957
- * CVE-2017-14859
- * CVE-2017-14860
- * CVE-2017-14862
- * CVE-2017-14864
- * CVE-2017-14857
- add upstream patch fixing segfault on photos from pentax cameras

* Tue Jun 20 2017 neoclust <neoclust> 0.26-2.mga6
+ Revision: 1107938
- Fix default build options

* Tue Jun 20 2017 akien <akien> 0.26-1.mga6
+ Revision: 1107926
- BR cmake

  + neoclust <neoclust>
    - New version 0.26

* Mon Sep 05 2016 pterjan <pterjan> 0.25-4.mga6
+ Revision: 1050049
- Fix again parallel build as the patch had been disabled

* Fri Mar 04 2016 luigiwalser <luigiwalser> 0.25-3.mga6
+ Revision: 985700
- embedded copy of exempi should be compiled with BanAllEntityUsage (rhbz#888769)

* Sun Feb 14 2016 umeabot <umeabot> 0.25-2.mga6
+ Revision: 960053
- Mageia 6 Mass Rebuild

* Sun Aug 23 2015 neoclust <neoclust> 0.25-1.mga6
+ Revision: 868251
- New version 0.25

* Fri Feb 27 2015 pterjan <pterjan> 0.24-5.mga5
+ Revision: 817139
- Add opensuse patch fixing parallel build

* Thu Jan 08 2015 luigiwalser <luigiwalser> 0.24-4.mga5
+ Revision: 809356
- add upstream patch to fix CVE-2014-9449

* Wed Oct 15 2014 umeabot <umeabot> 0.24-3.mga5
+ Revision: 742701
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.24-2.mga5
+ Revision: 679062
- Mageia 5 Mass Rebuild

* Mon Feb 10 2014 dams <dams> 0.24-1.mga5
+ Revision: 588947
- new version 0.24
- update %%major
- clean specfile

* Fri Oct 18 2013 umeabot <umeabot> 0.23-4.mga4
+ Revision: 504210
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 0.23-3.mga3
+ Revision: 349867
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + boklm <boklm>
    - Update group: Graphics/Other -> Graphics/Utilities

* Fri Nov 09 2012 fwang <fwang> 0.23-2.mga3
+ Revision: 316594
- update rpm group
- update rpm group
- update rpm group

* Mon Jun 18 2012 fwang <fwang> 0.23-1.mga3
+ Revision: 261591
- update libmajor
- new version 0.23

* Sun Oct 09 2011 fwang <fwang> 0.22-1.mga2
+ Revision: 153403
- update libmajor
- new version 0.22

* Wed Apr 20 2011 pterjan <pterjan> 0.21.1-1.mga1
+ Revision: 89207
- Update to 0.21.1

* Fri Jan 14 2011 mikala <mikala> 0.21-1.mga1
+ Revision: 18068
- Drop mdk macros
- Remove BuildRoot
- imported package exiv2


* Wed Dec 01 2010 Funda Wang <fwang@mandriva.org> 0.21-1mdv2011.0
+ Revision: 604320
- fix BR
- new version 0.21

* Thu Sep 02 2010 Thierry Vignaud <tv@mandriva.org> 0.20-2mdv2011.0
+ Revision: 575202
- let the doc subpackage be noarch

* Tue Aug 03 2010 Emmanuel Andry <eandry@mandriva.org> 0.20-1mdv2011.0
+ Revision: 565526
- New version 0.20
- New major 9

* Wed Dec 30 2009 Frederik Himpe <fhimpe@mandriva.org> 0.19-1mdv2010.1
+ Revision: 484177
- Update to new version 0.19 (new major)

* Thu Jun 25 2009 Frederik Himpe <fhimpe@mandriva.org> 0.18.2-1mdv2010.0
+ Revision: 389178
- update to new version 0.18.2

* Thu Apr 16 2009 Helio Chissini de Castro <helio@mandriva.com> 0.18.1-1mdv2009.1
+ Revision: 367803
- UPgrade to bug fix release fixing digikam reported crashes

* Sat Dec 20 2008 Funda Wang <fwang@mandriva.org> 0.18-1mdv2009.1
+ Revision: 316542
- New verison 0.18

* Mon Jun 23 2008 Tiago Salem <salem@mandriva.com.br> 0.17.1-1mdv2009.0
+ Revision: 228078
- version 0.17.1
- fix CVE-2008-2696

* Fri Jun 20 2008 Helio Chissini de Castro <helio@mandriva.com> 0.17-1mdv2009.0
+ Revision: 227482
- New upstream version
- Moved docs for a separated doc package instead of devel package
- Fixed devel package naming, as new major was making impossible to upgrade

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Feb 05 2008 Anssi Hannula <anssi@mandriva.org> 0.16-3mdv2008.1
+ Revision: 162757
- remove obsoletes on old library

* Sat Jan 26 2008 Anssi Hannula <anssi@mandriva.org> 0.16-2mdv2008.1
+ Revision: 158233
- obsolete old library name

* Fri Jan 25 2008 Marcelo Ricardo Leitner <mrl@mandriva.com> 0.16-1mdv2008.1
+ Revision: 157944
- New stable upstream: 0.16. Closes: #36634

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Nov 26 2007 Thierry Vignaud <tv@mandriva.org> 0.16-0.pre1.3mdv2008.1
+ Revision: 112174
- further improved libification (anssi)

* Mon Nov 26 2007 Thierry Vignaud <tv@mandriva.org> 0.16-0.pre1.2mdv2008.1
+ Revision: 112173
- use more macros
- fix library name (which fixes upgrading from previous bogus packages using a
  wrong major as a side effect)

* Sun Nov 25 2007 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.16-0.pre1.1mdv2008.1
+ Revision: 111869
- Add Expat-devel as BuildRequire
- 0.16 pre1

  + Thierry Vignaud <tv@mandriva.org>
    - do not duplicate description
    - description is not copyright

* Tue Oct 16 2007 Angelo Naselli <anaselli@mandriva.org> 0.15-3mdv2008.1
+ Revision: 98947
- Added documents into developer package

* Tue Sep 18 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.15-2mdv2008.0
+ Revision: 89634
- rebuild

* Mon Aug 27 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 0.15-1mdv2008.0
+ Revision: 71867
- New upstream: 0.15

* Fri Apr 20 2007 Angelo Naselli <anaselli@mandriva.org> 0.14-1mdv2008.0
+ Revision: 16204
- new version 0.14


* Sun Mar 04 2007 Angelo Naselli <anaselli@mandriva.org> 0.13-1mdv2007.0
+ Revision: 132257
- new version 0.13

* Mon Dec 04 2006 Angelo Naselli <anaselli@mandriva.org> 0.12-3mdv2007.1
+ Revision: 90545
- Added version provided by libexiv-devel

* Sun Dec 03 2006 Angelo Naselli <anaselli@mandriva.org> 0.12-2mdv2007.1
+ Revision: 90288
- added zlib-devel requirement

  + Laurent Montel <lmontel@mandriva.com>
    - 0.12.0
    - Import exiv2

* Sun Sep 10 2006 Emmanuel Andry <eandry@mandriva.org> 0.10-2mdv2007.0
- fix x86_64 build

* Wed Aug 09 2006 Till Kamppeter <till@mandriva.com> 0.10-1mdv2007.0
- Initial release

